@@ -360,7 +360,7 @@ varimp <- function(object, rvar, lev, data = NULL, seed = 1234) {
       object,
       target = rvar,
       method = "permute",
-      metric = "r2", # "rmse"
+      metric = "rsq", # "rmse"
       pred_wrapper = pred_fun,
       train = data
     )
@@ -715,4 +715,4 @@ cv.nn <- function(object, K = 5, repeats = 1, decay = seq(0, 1, .2), size = 1:5,
   ## show evaluation metric in column name
   colnames(out)[1] <- cn
   out
-}
\ No newline at end of file
+}
