@@ -334,9 +334,9 @@ summary.regress <- function(object, sum_check = "", conf_lev = .95,
       sub_form <- paste(object$rvar, "~ 1")
 
       vars <- object$evar
-      if (object$int != "" && length(vars) > 1) {
+      if (!is.empty(object$int) && length(vars) > 1) {
         ## updating test_var if needed
-        test_var <- test_specs(test_var, object$int)
+        test_var <- unique(c(test_var, test_specs(test_var, object$int)))
         vars <- c(vars, object$int)
       }
 
@@ -411,13 +411,19 @@ summary.regress <- function(object, sum_check = "", conf_lev = .95,
 #' @param hline Add a horizontal line at the average of the target variable. When set to FALSE
 #'   no line is added. When set to a specific number, the horizontal line will be added at that value
 #' @param nr Number of values to use to generate predictions for a numeric explanatory variable
+#' @param minq Quantile to use for the minimum value for simulation of numeric variables
+#' @param maxq Quantile to use for the maximum value for simulation of numeric variables
 #'
 #' @importFrom radiant.data visualize
 #' @importFrom rlang .data
+#' @importFrom tidyselect where
 #'
 #' @export
-pred_plot <- function(x, plot_list = list(), incl, incl_int, fix = TRUE, hline = TRUE, nr = 20) {
+pred_plot <- function(x, plot_list = list(), incl, incl_int, fix = TRUE, hline = TRUE, nr = 20, minq = 0.025, maxq = 0.975) {
   min_max <- c(Inf, -Inf)
+  minx <- function(x) quantile(x, p = minq)
+  maxx <- function(x) quantile(x, p = maxq)
+
   calc_ylim <- function(lab, lst, min_max) {
     if (isTRUE(fix)) {
       vals <- lst[[lab]]
@@ -434,15 +440,11 @@ pred_plot <- function(x, plot_list = list(), incl, incl_int, fix = TRUE, hline =
 
   mod_dat <- x$model$model # [, -1, drop = FALSE]
   pvar <- "Prediction"
-
   set_pred_name <- function(pred) {
     if (!pvar %in% colnames(pred)) {
-      pname <- colnames(pred)[ncol(mod_dat) + 1]
-      if (pname != pvar) {
-        cn <- colnames(pred)
-        cn[cn == pname] <- pvar
-        colnames(pred) <- cn
-      }
+      pname <- colnames(pred)[ncol(mod_dat)]
+      colnames(pred)[colnames(pred) == pname] <- pvar
+      pred <- select(pred, 1:Prediction)
     }
     return(pred)
   }
@@ -452,11 +454,17 @@ pred_plot <- function(x, plot_list = list(), incl, incl_int, fix = TRUE, hline =
     is_num <- sapply(df, is.numeric)
     if (is.numeric(df[[pn]])) {
       num_range <- df[[pn]] %>%
-        (function(x) seq(min(x), max(x), length.out = nr)) %>%
+        (function(x) seq(minx(x), maxx(x), length.out = nr)) %>%
         paste0(collapse = ", ")
-      pred <- predict(x, pred_cmd = glue("{pn} = c({num_range})")) %>% set_pred_name()
+      pred <- predict(x, pred_cmd = glue("{pn} = c({num_range})"), se = FALSE) %>%
+        set_pred_name()
+    } else if (is.logical(df[[pn]])) {
+      pred <- predict(x, pred_cmd = glue("{pn} = c(FALSE, TRUE)"), se = FALSE) %>%
+        set_pred_name()
+      pred[[pn]] <- factor(pred[[pn]], levels = c(FALSE, TRUE))
     } else {
-      pred <- predict(x, pred_cmd = glue("{pn} = levels({pn})")) %>% set_pred_name()
+      pred <- predict(x, pred_cmd = glue("{pn} = levels({pn})"), se = FALSE) %>%
+        set_pred_name()
     }
     plot_list[[pn]] <- visualize(pred, xvar = pn, yvar = pvar, type = "line", custom = TRUE) + labs(y = NULL)
     min_max <- calc_ylim(pvar, pred, min_max)
@@ -470,18 +478,31 @@ pred_plot <- function(x, plot_list = list(), incl, incl_int, fix = TRUE, hline =
       # 2 numeric variables
       cn <- colnames(df)
       num_range1 <- df[[cn[1]]] %>%
-        (function(x) seq(min(x), max(x), length.out = nr)) %>%
+        (function(x) seq(minx(x), maxx(x), length.out = nr)) %>%
         paste0(collapse = ", ")
       num_range2 <- df[[cn[2]]] %>%
-        (function(x) seq(min(x), max(x), length.out = nr)) %>%
+        (function(x) seq(minx(x), maxx(x), length.out = nr)) %>%
         paste0(collapse = ", ")
-      pred <- predict(x, pred_cmd = glue("{cn[1]} = c({num_range1}), {cn[2]} = c({num_range2})")) %>% set_pred_name()
+      pred <- predict(x, pred_cmd = glue("{cn[1]} = c({num_range1}), {cn[2]} = c({num_range2})"), se = FALSE) %>% set_pred_name()
       plot_list[[paste0(pn_lab, "_tile")]] <- ggplot(pred, aes(x = .data[[cn[1]]], y = .data[[cn[2]]], fill = .data[[pvar]])) +
         geom_tile()
     } else if (sum(is_num) == 0) {
       # 2 categorical variables
       cn <- colnames(df)
-      pred <- predict(x, pred_cmd = glue("{cn[1]} = levels({cn[1]}), {cn[2]} = levels({cn[2]})")) %>% set_pred_name()
+      is_lgcl  <- sapply(df, is.logical)
+      if (sum(is_lgcl) == 2) {
+          pred <- predict(x, pred_cmd = glue("{cn[1]} = c(FALSE, TRUE), {cn[2]} = c(FALSE, TRUE)"), se = FALSE) %>% set_pred_name()
+      } else if (sum(is_lgcl) == 1) {
+        if (is_lgcl[1]) {
+          pred <- predict(x, pred_cmd = glue("{cn[2]} = levels({cn[1]}), {cn[2]} = c(FALSE, TRUE)"), se = FALSE) %>% set_pred_name()
+        } else {
+          pred <- predict(x, pred_cmd = glue("{cn[1]} = levels({cn[1]}), {cn[2]} = c(FALSE, TRUE)"), se = FALSE) %>% set_pred_name()
+        }
+      } else {
+        pred <- predict(x, pred_cmd = glue("{cn[1]} = levels({cn[1]}), {cn[2]} = levels({cn[2]})"), se = FALSE) %>% set_pred_name()
+      }
+
+      pred <- pred %>% mutate(across(where(is.logical), function(x) factor(x, levels = c(FALSE, TRUE))))
       plot_list[[pn_lab]] <- visualize(
         pred,
         xvar = cn[1], yvar = pvar, type = "line", color = cn[2], custom = TRUE
@@ -493,9 +514,17 @@ pred_plot <- function(x, plot_list = list(), incl, incl_int, fix = TRUE, hline =
       cn_fct <- cn[!is_num]
       cn_num <- cn[is_num]
       num_range <- df[[cn_num[1]]] %>%
-        (function(x) seq(min(x), max(x), length.out = 20)) %>%
+        (function(x) seq(minx(x), maxx(x), length.out = 20)) %>%
         paste0(collapse = ", ")
-      pred <- predict(x, pred_cmd = glue("{cn_num[1]} = c({num_range}), {cn_fct} = levels({cn_fct})")) %>% set_pred_name()
+
+      if (is.logical(df[[cn_fct]])) {
+        pred <- predict(x, pred_cmd = glue("{cn_num[1]} = c({num_range}), {cn_fct} = c(FALSE, TRUE)"), se = FALSE) %>%
+          set_pred_name()
+        pred[[cn_fct]] <- factor(pred[[cn_fct]], levels = c(FALSE, TRUE))
+      } else {
+        pred <- predict(x, pred_cmd = glue("{cn_num[1]} = c({num_range}), {cn_fct} = levels({cn_fct})"), se = FALSE) %>% set_pred_name()
+      }
+
       plot_list[[pn_lab]] <- plot(pred, xvar = cn_num[1], yvar = pvar, color = cn_fct, custom = TRUE) + labs(y = NULL)
       min_max <- calc_ylim(pvar, pred, min_max)
     }
@@ -507,7 +536,14 @@ pred_plot <- function(x, plot_list = list(), incl, incl_int, fix = TRUE, hline =
     }
   }
 
-  if (isTRUE(hline)) hline <- mean(mod_dat[[1]])
+  if (isTRUE(hline)) {
+    y <- mod_dat[[1]]
+    if (is.factor(y)) {
+      lev <- ifelse(is.empty(x$lev), levels(y)[1], x$lev)
+      y <- y == lev
+    }
+    hline <- mean(y)
+  }
   if (is.numeric(hline)) {
     for (pn_lab in intersect(c(incl, incl_int), names(plot_list))) {
       plot_list[[pn_lab]] <- plot_list[[pn_lab]] +
@@ -518,7 +554,6 @@ pred_plot <- function(x, plot_list = list(), incl, incl_int, fix = TRUE, hline =
   return(plot_list)
 }
 
-
 #' Create Partial Dependence Plots
 #'
 #' @param x Return value from a model
@@ -529,15 +564,23 @@ pred_plot <- function(x, plot_list = list(), incl, incl_int, fix = TRUE, hline =
 #'   Set to FALSE to have y-axis limits set by ggplot2 for each plot
 #' @param hline Add a horizontal line at the average of the target variable. When set to FALSE
 #'   no line is added. When set to a specific number, the horizontal line will be added at that value
+#' @param nr Number of values to use to generate predictions for a numeric explanatory variable
+#' @param minq Quantile to use for the minimum value for simulation of numeric variables
+#' @param maxq Quantile to use for the maximum value for simulation of numeric variables
 #'
 #' @importFrom radiant.data visualize
 #' @importFrom pdp partial
 #' @importFrom ggplot2 autoplot
+#' @importFrom tidyselect where
 #'
 #' @export
-pdp_plot <- function(x, plot_list = list(), incl, incl_int, fix = TRUE, hline = TRUE) {
+pdp_plot <- function(x, plot_list = list(), incl, incl_int, fix = TRUE, hline = TRUE, nr = 20, minq = 0.025, maxq = 0.975) {
   pdp_list <- list()
   min_max <- c(Inf, -Inf)
+  minx <- function(x) quantile(x, p = minq)
+  maxx <- function(x) quantile(x, p = maxq)
+  probs <- seq(minq, maxq, length.out = nr)
+
   calc_ylim <- function(lab, lst, min_max) {
     if (isTRUE(fix)) {
       vals <- lst[[lab]]
@@ -549,21 +592,47 @@ pdp_plot <- function(x, plot_list = list(), incl, incl_int, fix = TRUE, hline =
     }
   }
 
+  mod_dat <- x$model$model
+  pvar <- "Prediction"
+  set_pred_name <- function(pred) {
+    if (!pvar %in% colnames(pred)) {
+      pname <- colnames(pred)[ncol(mod_dat)]
+      colnames(pred)[colnames(pred) == pname] <- pvar
+      pred <- select(pred, 1:Prediction)
+    }
+    return(pred)
+  }
+
   if (length(incl_int) > 0) {
     incl_int <- strsplit(incl_int, ":")
   }
   incl <- c(incl, incl_int)
   for (pn in incl) {
+    df <- select(x$model$model, {{ pn }})
     pn_lab <- paste0(pn, collapse = ":")
-    pdp_list[[pn_lab]] <- pdp::partial(
-      x$model,
-      pred.var = pn,
-      plot = FALSE,
-      prob = x$type == "classification",
-      train = x$model$model
-    )
-    if (length(pn) < 2 || sum(c(is.numeric(x$model$model[[pn[1]]]), is.numeric(x$model$model[[pn[2]]]))) < 2) {
+    if (length(pn) < 2 & is.logical(df[[pn_lab]])) {
+      pdp_list[[pn_lab]] <- pdp::partial(
+        x$model,
+        pred.var = pn,
+        plot = FALSE,
+        prob = x$type == "classification",
+        train = x$model$model
+      )
       min_max <- calc_ylim("yhat", pdp_list[[pn_lab]], min_max)
+    } else if (length(pn) < 2 || sum(sapply(df, is.numeric)) < 2) {
+      pdp_list[[pn_lab]] <- pdp::partial(
+        x$model,
+        pred.var = pn,
+        plot = FALSE,
+        quantiles = TRUE,
+        probs = probs,
+        prob = x$type == "classification",
+        train = x$model$model
+      )
+      min_max <- calc_ylim("yhat", pdp_list[[pn_lab]], min_max)
+    } else {
+      # issues with autoplot of interactions between two numeric variables
+      pdp_list[[pn_lab]] <- df %>% mutate(fake_pred = 0)
     }
   }
 
@@ -571,14 +640,34 @@ pdp_plot <- function(x, plot_list = list(), incl, incl_int, fix = TRUE, hline =
     df <- pdp_list[[pn_lab]]
     is_num <- sapply(df, is.numeric)
     if (ncol(df) == 2) {
-      plot_list[[pn_lab]] <- autoplot(pdp_list[[pn_lab]]) +
-        labs(y = NULL)
+      if (is.logical(df[[1]])) {
+        cn_fct <- colnames(df)[1]
+        df[[cn_fct]] <- factor(df[[cn_fct]], levels = c(FALSE, TRUE))
+        plot_list[[pn_lab]] <- visualize(df, xvar = cn_fct, yvar = "yhat", type = "line", custom = TRUE) +
+          labs(y = NULL)
+      } else {
+        plot_list[[pn_lab]] <- autoplot(pdp_list[[pn_lab]]) +
+          labs(y = NULL)
+      }
     } else if (sum(is_num) == 3) {
       # 2 numeric variables
-      plot_list[[paste0(pn_lab, "_tile")]] <- autoplot(pdp_list[[pn_lab]])
+      cn <- colnames(df)
+      num_range1 <- df[[cn[1]]] %>%
+        (function(x) seq(minx(x), maxx(x), length.out = nr)) %>%
+        paste0(collapse = ", ")
+      num_range2 <- df[[cn[2]]] %>%
+        (function(x) seq(minx(x), maxx(x), length.out = nr)) %>%
+        paste0(collapse = ", ")
+      pred <- predict(x, pred_cmd = glue("{cn[1]} = c({num_range1}), {cn[2]} = c({num_range2})"), se = FALSE) %>%
+        set_pred_name()
+      plot_list[[paste0(pn_lab, "_tile")]] <- ggplot(pred, aes(x = .data[[cn[1]]], y = .data[[cn[2]]], fill = .data[[pvar]])) +
+        geom_tile()
+      # giving weird results "blotchy" graphs with lots of empty space
+      # plot_list[[paste0(pn_lab, "_tile")]] <- autoplot(pdp_list[[pn_lab]])
     } else if (sum(is_num) == 1) {
       # 2 categorical variables
       cn <- colnames(df)
+      df <- df %>% mutate(across(where(is.logical), function(x) factor(x, levels = c(FALSE, TRUE))))
       plot_list[[pn_lab]] <- visualize(
         df,
         xvar = cn[1], yvar = cn[3], type = "line", color = cn[2], custom = TRUE
@@ -603,7 +692,14 @@ pdp_plot <- function(x, plot_list = list(), incl, incl_int, fix = TRUE, hline =
     }
   }
 
-  if (isTRUE(hline)) hline <- mean(x$model$model[[1]])
+  if (isTRUE(hline)) {
+    y <- mod_dat[[1]]
+    if (is.factor(y)) {
+      lev <- ifelse(is.empty(x$lev), levels(y)[1], x$lev)
+      y <- y == lev
+    }
+    hline <- mean(y)
+  }
   if (is.numeric(hline)) {
     for (pn_lab in to_augment) {
       plot_list[[pn_lab]] <- plot_list[[pn_lab]] +
@@ -1539,4 +1635,4 @@ test_specs <- function(tv, int) {
   } else {
     tv
   }
-}
\ No newline at end of file
+}
