@@ -230,7 +230,7 @@ output$ui_gbt_nrobs <- renderUI({
 run_refresh(gbt_args, "gbt", tabs = "tabs_gbt", label = "Estimate model", relabel = "Re-estimate model")
 
 output$ui_gbt <- renderUI({
-  req(input$dataset)
+  # req(input$dataset)
   tagList(
     conditionalPanel(
       condition = "input.tabs_gbt == 'Summary'",
@@ -752,4 +752,4 @@ observeEvent(input$gbt_screenshot, {
 observeEvent(input$modal_gbt_screenshot, {
   gbt_report()
   removeModal() ## remove shiny modal after save
-})
\ No newline at end of file
+})
