@@ -20,6 +20,9 @@ reg_lines <- c("Line" = "line", "Loess" = "loess", "Jitter" = "jitter")
 reg_plots <- c(
   "None" = "none", "Distribution" = "dist",
   "Correlations" = "correlations", "Scatter" = "scatter",
+  "Permutation Importance" = "vip",
+  "Prediction plots" = "pred_plot",
+  "Partial Dependence" = "pdp",
   "Dashboard" = "dashboard",
   "Residual vs explanatory" = "resid_pred",
   "Coefficient plot" = "coef",
@@ -32,6 +35,8 @@ reg_args <- as.list(formals(regress))
 reg_inputs <- reactive({
   ## loop needed because reactive values don't allow single bracket indexing
   reg_args$data_filter <- if (input$show_filter) input$data_filter else ""
+  reg_args$arr <- if (input$show_filter) input$data_arrange else ""
+  reg_args$rows <- if (input$show_filter) input$data_rows else ""
   reg_args$dataset <- input$dataset
   for (i in r_drop(names(reg_args))) {
     reg_args[[i]] <- input[[paste0("reg_", i)]]
@@ -146,13 +151,40 @@ output$ui_reg_evar <- renderUI({
 output$ui_reg_incl <- renderUI({
   req(available(input$reg_evar))
   vars <- input$reg_evar
+  if (input[["reg_plots"]] == "coef") {
+    vars_init <- vars
+  } else {
+    vars_init <- c()
+  }
   selectInput(
     inputId = "reg_incl", label = "Explanatory variables to include:", choices = vars,
-    selected = state_multiple("reg_incl", vars, vars),
+    selected = state_multiple("reg_incl", vars, vars_init),
     multiple = TRUE, size = min(10, length(vars)), selectize = FALSE
   )
 })
 
+output$ui_reg_incl_int <- renderUI({
+  req(available(input$reg_evar))
+  choices <- character(0)
+  vars <- input$reg_evar
+  ## list of interaction terms to show
+  if (length(vars) > 1) {
+    choices <- c(choices, iterms(vars, 2))
+  } else {
+    updateSelectInput(session, "reg_incl_int", choices = choices, selected = choices)
+    return()
+  }
+  selectInput(
+    "reg_incl_int",
+    label = "2-way interactions to explore:",
+    choices = choices,
+    selected = state_multiple("reg_incl_int", choices),
+    multiple = TRUE,
+    size = min(8, length(choices)),
+    selectize = FALSE
+  )
+})
+
 output$ui_reg_test_var <- renderUI({
   req(available(input$reg_evar))
   vars <- input$reg_evar
@@ -189,8 +221,8 @@ output$ui_reg_show_interactions <- renderUI({
 output$ui_reg_int <- renderUI({
   choices <- character(0)
   if (isolate("reg_show_interactions" %in% names(input)) &&
-    radiant.data::is_empty(input$reg_show_interactions)) {
-  } else if (radiant.data::is_empty(input$reg_show_interactions)) {
+    is.empty(input$reg_show_interactions)) {
+  } else if (is.empty(input$reg_show_interactions)) {
     return()
   } else {
     vars <- input$reg_evar
@@ -255,7 +287,7 @@ run_refresh(reg_args, "reg", tabs = "tabs_regress", label = "Estimate model", re
 
 ## data ui and tabs
 output$ui_regress <- renderUI({
-  req(input$dataset)
+  # req(input$dataset)
   tagList(
     conditionalPanel(
       condition = "input.tabs_regress == 'Summary'",
@@ -336,9 +368,16 @@ output$ui_regress <- renderUI({
           selected = state_single("reg_plots", reg_plots)
         ),
         conditionalPanel(
-          condition = "input.reg_plots == 'coef'",
+          condition = "input.reg_plots == 'coef' | input.reg_plots == 'pdp' | input.reg_plots == 'pred_plot'",
           uiOutput("ui_reg_incl"),
-          checkboxInput("reg_intercept", "Include intercept", state_init("reg_intercept", FALSE))
+          conditionalPanel(
+            condition = "input.reg_plots == 'coef'",
+            checkboxInput("reg_intercept", "Include intercept", state_init("reg_intercept", FALSE))
+          ),
+          conditionalPanel(
+            condition = "input.reg_plots == 'pdp' | input.reg_plots == 'pred_plot'",
+            uiOutput("ui_reg_incl_int")
+          )
         ),
         conditionalPanel(
           condition = "input.reg_plots == 'correlations' |
@@ -385,30 +424,36 @@ reg_plot <- reactive({
   if (reg_available() != "available") {
     return()
   }
-  if (radiant.data::is_empty(input$reg_plots, "none")) {
+  if (is.empty(input$reg_plots, "none")) {
     return()
   }
 
   # specifying plot heights
   plot_height <- 500
   plot_width <- 650
-  nrVars <- length(input$reg_evar) + 1
+  nr_vars <- length(input$reg_evar) + 1
 
   if (input$reg_plots == "dist") {
-    plot_height <- (plot_height / 2) * ceiling(nrVars / 2)
+    plot_height <- (plot_height / 2) * ceiling(nr_vars / 2)
   } else if (input$reg_plots == "dashboard") {
     plot_height <- 1.5 * plot_height
   } else if (input$reg_plots == "correlations") {
-    plot_height <- 150 * nrVars
-    plot_width <- 150 * nrVars
+    plot_height <- 150 * nr_vars
+    plot_width <- 150 * nr_vars
   } else if (input$reg_plots == "coef") {
-    if (input$reg_plots == "coef") {
-      incl <- paste0("^(", paste0(input$reg_incl, "[|]*", collapse = "|"), ")")
-      nr_coeff <- sum(grepl(incl, .regress()$coeff$label))
-      plot_height <- 300 + 20 * nr_coeff
-    }
+    incl <- paste0("^(", paste0(input$reg_incl, "[|]*", collapse = "|"), ")")
+    nr_coeff <- sum(grepl(incl, .regress()$coeff$label))
+    plot_height <- 300 + 20 * nr_coeff
   } else if (input$reg_plots %in% c("scatter", "resid_pred")) {
-    plot_height <- (plot_height / 2) * ceiling((nrVars - 1) / 2)
+    plot_height <- (plot_height / 2) * ceiling((nr_vars - 1) / 2)
+  } else if (input$reg_plots == "vip") {
+    plot_height <- max(500, 30 * nr_vars)
+  } else if (input$reg_plots %in% c("pdp", "pred_plot")) {
+    nr_vars <- length(input$reg_incl) + length(input$reg_incl_int)
+    plot_height <- max(250, ceiling(nr_vars / 2) * 250)
+    if (length(input$reg_incl_int) > 0) {
+      plot_width <- plot_width + min(2, length(input$reg_incl_int)) * 90
+    }
   }
 
   list(plot_width = plot_width, plot_height = plot_height)
@@ -416,16 +461,12 @@ reg_plot <- reactive({
 
 reg_plot_width <- function() {
   reg_plot() %>%
-    {
-      if (is.list(.)) .$plot_width else 650
-    }
+    (function(x) if (is.list(x)) x$plot_width else 650)
 }
 
 reg_plot_height <- function() {
   reg_plot() %>%
-    {
-      if (is.list(.)) .$plot_height else 500
-    }
+    (function(x) if (is.list(x)) x$plot_height else 500)
 }
 
 reg_pred_plot_height <- function() {
@@ -516,13 +557,13 @@ reg_available <- eventReactive(input$reg_run, {
   if (reg_available() != "available") {
     return(reg_available())
   }
-  if (radiant.data::is_empty(input$reg_predict, "none")) {
+  if (is.empty(input$reg_predict, "none")) {
     return("** Select prediction input **")
   }
-  if ((input$reg_predict == "data" || input$reg_predict == "datacmd") && radiant.data::is_empty(input$reg_pred_data)) {
+  if ((input$reg_predict == "data" || input$reg_predict == "datacmd") && is.empty(input$reg_pred_data)) {
     return("** Select data for prediction **")
   }
-  if (input$reg_predict == "cmd" && radiant.data::is_empty(input$reg_pred_cmd)) {
+  if (input$reg_predict == "cmd" && is.empty(input$reg_pred_cmd)) {
     return("** Enter prediction commands **")
   }
 
@@ -536,16 +577,14 @@ reg_available <- eventReactive(input$reg_run, {
 
 .predict_print_regress <- reactive({
   .predict_regress() %>%
-    {
-      if (is.character(.)) cat(., "\n") else print(.)
-    }
+    (function(x) if (is.character(x)) cat(x, "\n") else print(x))
 })
 
 .predict_plot_regress <- reactive({
   req(
     pressed(input$reg_run), input$reg_pred_plot,
     available(input$reg_xvar),
-    !radiant.data::is_empty(input$reg_predict, "none")
+    !is.empty(input$reg_predict, "none")
   )
 
   withProgress(message = "Generating prediction plot", value = 1, {
@@ -556,12 +595,13 @@ reg_available <- eventReactive(input$reg_run, {
 .plot_regress <- reactive({
   if (not_pressed(input$reg_run)) {
     return("** Press the Estimate button to estimate the model **")
-  } else if (radiant.data::is_empty(input$reg_plots, "none")) {
+  } else if (is.empty(input$reg_plots, "none")) {
     return("Please select a regression plot from the drop-down menu")
   } else if (reg_available() != "available") {
     return(reg_available())
   }
-  if (!input$reg_plots %in% c("coef", "dist", "influence")) req(input$reg_nrobs)
+  if (!input$reg_plots %in% c("coef", "dist", "influence", "vip", "pdp", "pred_plot")) req(input$reg_nrobs)
+  check_for_pdp_pred_plots("reg")
   withProgress(message = "Generating plots", value = 1, {
     if (input$reg_plots == "correlations") {
       capture_plot(do.call(plot, c(list(x = .regress()), reg_plot_inputs())))
@@ -571,29 +611,42 @@ reg_available <- eventReactive(input$reg_run, {
   })
 })
 
+check_plot_inputs <- function(inp) {
+  if (inp$plots %in% c("correlations", "scatter", "dashboard", "resid_pred")) {
+    inp$nrobs <- as_integer(inp$nrobs)
+  } else {
+    inp$nrobs <- NULL
+  }
+
+  if (sum(inp$plots %in% c("coef", "pdp", "pred_plot")) == 0) {
+    inp$incl <- NULL
+    inp$incl_int <- NULL
+  }
+
+  if (inp$plots == "coef") {
+    inp$incl_int <- NULL
+  }
+
+  inp
+}
+
 regress_report <- function() {
-  if (radiant.data::is_empty(input$reg_evar)) {
+  if (is.empty(input$reg_evar)) {
     return(invisible())
   }
   outputs <- c("summary")
   inp_out <- list("", "")
   inp_out[[1]] <- clean_args(reg_sum_inputs(), reg_sum_args[-1])
   figs <- FALSE
-  if (!radiant.data::is_empty(input$reg_plots, "none")) {
-    rpi <- reg_plot_inputs()
-    if (!input$reg_plots %in% c("correlations", "scatter", "dashboard", "resid_pred")) {
-      rpi$nrobs <- NULL
-    } else {
-      rpi$nrobs <- as_integer(rpi$nrobs)
-    }
-
-    inp_out[[2]] <- clean_args(rpi, reg_plot_args[-1])
+  if (!is.empty(input$reg_plots, "none")) {
+    inp <- check_plot_inputs(reg_plot_inputs())
+    inp_out[[2]] <- clean_args(inp, reg_plot_args[-1])
     inp_out[[2]]$custom <- FALSE
     outputs <- c(outputs, "plot")
     figs <- TRUE
   }
 
-  if (!radiant.data::is_empty(input$reg_store_res_name)) {
+  if (!is.empty(input$reg_store_res_name)) {
     fixed <- fix_names(input$reg_store_res_name)
     updateTextInput(session, "reg_store_res_name", value = fixed)
     xcmd <- paste0(input$dataset, " <- store(", input$dataset, ", result, name = \"", fixed, "\")\n")
@@ -601,16 +654,16 @@ regress_report <- function() {
     xcmd <- ""
   }
 
-  if (!radiant.data::is_empty(input$reg_predict, "none") &&
-    (!radiant.data::is_empty(input$reg_pred_data) || !radiant.data::is_empty(input$reg_pred_cmd))) {
+  if (!is.empty(input$reg_predict, "none") &&
+    (!is.empty(input$reg_pred_data) || !is.empty(input$reg_pred_cmd))) {
     pred_args <- clean_args(reg_pred_inputs(), reg_pred_args[-1])
 
-    if (!radiant.data::is_empty(pred_args$pred_cmd)) {
-      pred_args$pred_cmd <- strsplit(pred_args$pred_cmd, ";")[[1]]
+    if (!is.empty(pred_args$pred_cmd)) {
+      pred_args$pred_cmd <- strsplit(pred_args$pred_cmd, ";\\s*")[[1]]
     } else {
       pred_args$pred_cmd <- NULL
     }
-    if (!radiant.data::is_empty(pred_args$pred_data)) {
+    if (!is.empty(pred_args$pred_data)) {
       pred_args$pred_data <- as.symbol(pred_args$pred_data)
     } else {
       pred_args$pred_data <- NULL
@@ -629,7 +682,7 @@ regress_report <- function() {
       )
     }
 
-    if (input$reg_pred_plot && !radiant.data::is_empty(input$reg_xvar)) {
+    if (input$reg_pred_plot && !is.empty(input$reg_xvar)) {
       inp_out[[3 + figs]] <- clean_args(reg_pred_plot_inputs(), reg_pred_plot_args[-1])
       inp_out[[3 + figs]]$result <- "pred"
       outputs <- c(outputs, "plot")
@@ -664,7 +717,7 @@ observeEvent(input$reg_store_res, {
 })
 
 observeEvent(input$reg_store_pred, {
-  req(!radiant.data::is_empty(input$reg_pred_data), pressed(input$reg_run))
+  req(!is.empty(input$reg_pred_data), pressed(input$reg_run))
   pred <- .predict_regress()
   if (is.null(pred)) {
     return()
@@ -749,4 +802,4 @@ observeEvent(input$regress_screenshot, {
 observeEvent(input$modal_regress_screenshot, {
   regress_report()
   removeModal() ## remove shiny modal after save
-})
\ No newline at end of file
+})
